.. vim: set fileencoding=utf-8 :

.. This file contains all links we use for documentation in a centralized place
.. Place here references to all citations in lower case

.. _numpy: http://numpy.scipy.org
.. _scipy: http://www.scipy.org
.. _pytest: https://pytest.org/
.. _miniconda: https://docs.conda.io/en/latest/miniconda.html
.. _pypi: http://pypi.python.org
.. _setuptools: https://pypi.org/project/setuptools/
.. _sphinx: http://sphinx.pocoo.org
.. _gplv3: http://www.gnu.org/licenses/gpl-3.0.en.html
.. _dataset: https://archive.ics.uci.edu/ml/datasets/human+activity+recognition+using+smartphones
